pub fn run_plugin_batch(
manifest: &PluginManifest,
stage: PluginStage,
payloads: &[Value],
) -> Result<Vec<PluginResponse>>Expand description
Execute a plugin for multiple payloads with default execution policy.
pub fn run_plugin_batch(
manifest: &PluginManifest,
stage: PluginStage,
payloads: &[Value],
) -> Result<Vec<PluginResponse>>Execute a plugin for multiple payloads with default execution policy.